Logo Mibo

AListToMapNode<'K, 'V> Type

An adaptive map of a list of entries (FDA AMap.ofAList parity). The list deltas are converted to map deltas: an insert or update sets the key, a remove drops the key. The mirror (key per input position) is aligned with the source; a key update replaces the entry in place.

Constructors

Constructor Description

AListToMapNode(source)

Full Usage: AListToMapNode(source)

Parameters:
Returns: AListToMapNode<'K, 'V>
source : IAdaptiveList<'K * 'V>
Returns: AListToMapNode<'K, 'V>

Type something to start searching.