Logo Mibo

CustomMapNode<'K, 'V> Type

An adaptive map whose content is driven by a compute function (FDA AMap.custom parity, pull model like CustomSetNode). The compute receives the current view and a delta builder and appends the operations that describe the change since the previous call.

Constructors

Constructor Description

CustomMapNode(compute)

Full Usage: CustomMapNode(compute)

Parameters:
Returns: CustomMapNode<'K, 'V>
compute : IReadOnlyDictionary<'K, 'V> -> MapDeltaBuilder<'K, 'V> -> unit
Returns: CustomMapNode<'K, 'V>

Type something to start searching.