Logo Mibo

CustomSetNode<'T> Type

An adaptive set whose content is driven by a compute function. The compute receives the current view and a delta builder; it appends the operations that describe the change since the previous call (consuming its own event queue, for example). Called on every read (poll), like ReaderSetNode. FDA ASet.custom parity, pull model.

Constructors

Constructor Description

CustomSetNode(compute)

Full Usage: CustomSetNode(compute)

Parameters:
Returns: CustomSetNode<'T>
compute : IReadOnlySet<'T> -> SetDeltaBuilder<'T> -> unit
Returns: CustomSetNode<'T>

Type something to start searching.