Logo Mibo

ListDeltaBuilder<'T> Type

A class-based delta builder for AList.custom computes. The struct ListDelta<'T> is passed by value (its counter would be copied); this class keeps the appends visible to the node.

Constructors

Constructor Description

ListDeltaBuilder()

Full Usage: ListDeltaBuilder()

Returns: ListDeltaBuilder<'T>
Returns: ListDeltaBuilder<'T>

Instance members

Instance member Description

this.Insert

Full Usage: this.Insert

Parameters:
    position : int
    value : 'T

Appends an insert operation. Positions refer to the state as of the previous operation.

position : int
value : 'T

this.Remove

Full Usage: this.Remove

Parameters:
    position : int

Appends a remove operation. Positions refer to the state as of the previous operation.

position : int

this.Update

Full Usage: this.Update

Parameters:
    position : int
    value : 'T

Appends an update operation. Positions refer to the state as of the previous operation.

position : int
value : 'T

Type something to start searching.