Logo Mibo

ListOpKind Type

The kind of a list operation (docs/ALIST-DESIGN.md 3.1).

Clear is used only in changeable-source transaction journals as a marker for a full clear; it is never part of a delivered delta (the source expands it into descending removes).

Record fields

Record Field Description

Clear

Full Usage: Clear

Field type: ListOpKind
Modifiers: static

Internal transaction-journal marker only; never delivered.

Field type: ListOpKind

Insert

Full Usage: Insert

Field type: ListOpKind
Modifiers: static

Insert before the element currently at Position; Position = count appends.

Field type: ListOpKind

Remove

Full Usage: Remove

Field type: ListOpKind
Modifiers: static

Remove the element currently at Position.

Field type: ListOpKind

Update

Full Usage: Update

Field type: ListOpKind
Modifiers: static

Replace the element currently at Position.

Field type: ListOpKind

Type something to start searching.