Logo Mibo

MapDelta<'K, 'V> Type

A map delta: upserted entries and removed keys since the previous delivery. The buffers are transient: valid only during the delivery that received the delta.

Record fields

Record Field Description

InDrain

Full Usage: InDrain

Field type: int[]
Modifiers: mutable
Field type: int[]

Rems

Full Usage: Rems

Field type: DeltaBuffer<'K>
Modifiers: mutable
Field type: DeltaBuffer<'K>

Sets

Full Usage: Sets

Field type: DeltaBuffer<'K * 'V>
Modifiers: mutable
Field type: DeltaBuffer<'K * 'V>

Instance members

Instance member Description

this.IsEmpty

Full Usage: this.IsEmpty

Returns: bool

Gets whether this delta contains no operations.

Returns: bool

this.Remove

Full Usage: this.Remove

Parameters:
    key : 'K

Appends a remove operation. For AMap.custom computes.

key : 'K

this.RemovedKeys

Full Usage: this.RemovedKeys

Returns: Memory<'K>

The keys removed. Transient: valid during the callback only.

Returns: Memory<'K>

this.Set

Full Usage: this.Set

Parameters:
    key : 'K
    value : 'V

Appends an upsert operation. For AMap.custom computes.

key : 'K
value : 'V

this.SetEntries

Full Usage: this.SetEntries

Returns: Memory<'K * 'V>

The entries set (added or updated). Transient: valid during the callback only.

Returns: Memory<'K * 'V>

Type something to start searching.