Logo Mibo

MapUseListNode<'T, 'W> Type

Maps every element, disposing the mapped value when the element leaves its position (FDA AList.mapUsei parity; the index is the int input position, the positional deviation). The output is 1:1 with the input; a removed or updated element disposes its mapped value. Disposing the node disposes all live mapped values and clears the output.

Constructors

Constructor Description

MapUseListNode(source, mapping)

Full Usage: MapUseListNode(source, mapping)

Parameters:
Returns: MapUseListNode<'T, 'W>
source : IAdaptiveList<'T>
mapping : int -> 'T -> 'W
Returns: MapUseListNode<'T, 'W>

Type something to start searching.