Logo Mibo

OfAvalMapNode<'K, 'V, 'S> Type

An adaptive map over an adaptive value of a sequence of entries. Every change of the value replaces the whole state and emits the diff as the delta (the rebuild boundary, like OfAvalSetNode).

Constructors

Constructor Description

OfAvalMapNode(value)

Full Usage: OfAvalMapNode(value)

Parameters:
Returns: OfAvalMapNode<'K, 'V, 'S>
value : IAdaptiveValue<'S>
Returns: OfAvalMapNode<'K, 'V, 'S>

Type something to start searching.