Logo Mibo

SetToMapNode<'K, 'V, 'T> Type

A map from a set: every element maps to an entry. When multiple elements map to one key, the last value wins (ofASetIgnoreDuplicates); a removal of an entry whose value is not the current one is a no-op (gated). mapSet uses an unconditional removal (a set key appears once).

Constructors

Constructor Description

SetToMapNode(source, toEntry, gated)

Full Usage: SetToMapNode(source, toEntry, gated)

Parameters:
    source : IAdaptiveSet<'T>
    toEntry : 'T -> 'K * 'V
    gated : bool

Returns: SetToMapNode<'K, 'V, 'T>
source : IAdaptiveSet<'T>
toEntry : 'T -> 'K * 'V
gated : bool
Returns: SetToMapNode<'K, 'V, 'T>

Type something to start searching.