Logo Mibo

ToSetListNode<'T> Type

An adaptive set of a list's elements, deduplicated (FDA AList.toASet parity). The list deltas are converted to set deltas with a per-value occurrence count: an element leaves the output only when its last occurrence leaves. The mirror is aligned with the input positions.

Constructors

Constructor Description

ToSetListNode(source)

Full Usage: ToSetListNode(source)

Parameters:
Returns: ToSetListNode<'T>
source : IAdaptiveList<'T>
Returns: ToSetListNode<'T>

Type something to start searching.