Header menu logo Mibo

Animation3DState Type

Runtime state for a playing 3D skeletal animation.

Each entity that needs independent animation must have its own Animation3DState. Call computeBonePalette after update to get the bone matrices for Draw3D.drawSkinnedMesh.

Record fields

Record Field Description

BlendDuration

Full Usage: BlendDuration

Field type: float32
Field type: float32

BlendProgress

Full Usage: BlendProgress

Field type: float32
Field type: float32

BlendTargetFrame

Full Usage: BlendTargetFrame

Field type: float32
Field type: float32

BlendTargetIndex

Full Usage: BlendTargetIndex

Field type: int
Field type: int

Clips

Full Usage: Clips

Field type: Animation3DClips
Field type: Animation3DClips

CurrentClipIndex

Full Usage: CurrentClipIndex

Field type: int
Field type: int

CurrentFrame

Full Usage: CurrentFrame

Field type: float32
Field type: float32

Finished

Full Usage: Finished

Field type: bool
Field type: bool

Loop

Full Usage: Loop

Field type: bool
Field type: bool

Speed

Full Usage: Speed

Field type: float32
Field type: float32

Type something to start searching.