Logo Mibo

Mibo.Diagnostics Namespace

Type/Module Description

Diagnostics

Access to the frame profiler and a display helper.

FrameProfiler

Collects frame measurements for the running game and serves screenshot requests.

FrameStats

Frame measurements collected over a time window.

MonoGameDiagnostics

Screen capture for the MonoGame backends.

RaylibDiagnostics

Screen capture for the raylib backend.

Type something to start searching.