Logo Mibo

DispatchMode Type

Controls when dispatched messages become eligible for processing.

In DispatchMode.Immediate, cascaded messages can be processed in the same Update call.

In DispatchMode.FrameBounded, messages dispatched while processing a frame are deferred until the next Update call.

Union cases

Union case Description

FrameBounded

Full Usage: FrameBounded

Defer messages dispatched during processing until the next frame.

Immediate

Full Usage: Immediate

Process newly dispatched messages immediately.

Instance members

Instance member Description

this.IsFrameBounded

Full Usage: this.IsFrameBounded

Returns: bool
Returns: bool

this.IsImmediate

Full Usage: this.IsImmediate

Returns: bool
Returns: bool

Type something to start searching.