Header menu logo Mibo

DirectionalLight3D Type

Directional light configuration for 3D scenes.

Record fields

Record Field Description

CastsShadows

Full Usage: CastsShadows

Field type: bool

Whether this directional light casts shadows.

Only the first shadow-casting directional light produces a shadow map. The forward PBR pipeline uses scalar (non-array) directional-light uniforms, so only one directional light is lit and shadowed. Additional directional lights are silently ignored by the shader. Set CastsShadows = false on extras.

Pipeline-dependent: Not all rendering pipelines support shadow casting. Pipelines that don't support shadows will ignore this field.

Field type: bool

Color

Full Usage: Color

Field type: Color

Color of the directional light.

Field type: Color

Direction

Full Usage: Direction

Field type: Vector3

Direction the light shines (should be normalized).

Field type: Vector3

Intensity

Full Usage: Intensity

Field type: float32

Intensity multiplier.

Field type: float32

Type something to start searching.