Material3D Module
Convenience values and functions for Material3D.
Functions and values
| Function or value |
Description
|
|
|
|
A default opaque white material with no textures and mid-roughness. Suitable as a fallback when no material is specified.
|
|
Reads material params from a native Effect
that exposes diffuse color/texture/alpha (
|
|
Reads material params from a ModelMeshPart's
baked native effect (the content-pipeline material). Convenience over
|
|
|
|
|
Full Usage:
withMetallicMap tex mat
Parameters:
Texture2D
mat : Material3D
Returns: Material3D
|
|
|
|
Full Usage:
withRoughnessMap tex mat
Parameters:
Texture2D
mat : Material3D
Returns: Material3D
|
Mibo