Logo Mibo

LightBuffers Module

Convenience builders for LightBuffers.

Functions and values

Function or value Description

clear lights

Full Usage: clear lights

Parameters:
Modifiers: inline

Resets all light accumulators to empty.

lights : LightBuffers

copyInto source target

Full Usage: copyInto source target

Parameters:
Modifiers: inline

Copies the contents of source into target, replacing whatever target held.

source : LightBuffers
target : LightBuffers

create dirCapacity pointCapacity spotCapacity

Full Usage: create dirCapacity pointCapacity spotCapacity

Parameters:
    dirCapacity : int
    pointCapacity : int
    spotCapacity : int

Returns: LightBuffers

Creates an empty accumulator with the given initial capacities.

dirCapacity : int
pointCapacity : int
spotCapacity : int
Returns: LightBuffers

Type something to start searching.