Logo Mibo

TransparentSkinnedInstancedCommand Type

A deferred transparent half of a skinned + instanced command. A mixed command defers up to two halves — its transparent-material parts (all instances) and the transparent tint instances of its opaque parts — each re-rendered through drawAnimatedModelInstanced with these filters.

Record fields

Record Field Description

BoneCount

Full Usage: BoneCount

Field type: int
Field type: int

Colors

Full Usage: Colors

Field type: Color[] voption
Field type: Color[] voption

DistanceSq

Full Usage: DistanceSq

Field type: float32
Field type: float32

InstanceCount

Full Usage: InstanceCount

Field type: int
Field type: int

InstanceFilter

Full Usage: InstanceFilter

Field type: InstanceOpacityFilter

Which instances this entry draws.

Field type: InstanceOpacityFilter

MatOverride

Full Usage: MatOverride

Field type: MaterialOverride voption
Field type: MaterialOverride voption

Model

Full Usage: Model

Field type: Model
Field type: Model

Palettes

Full Usage: Palettes

Field type: Matrix[]
Field type: Matrix[]

Transforms

Full Usage: Transforms

Field type: Matrix[]
Field type: Matrix[]

UnitFilter

Full Usage: UnitFilter

Field type: SkinnedInstancedUnitFilter

Which parts (draw units) this entry draws.

Field type: SkinnedInstancedUnitFilter

Type something to start searching.