Header menu logo Mibo

KeyCode Type

Backend-neutral keyboard key. Covers the standard US-layout key set that any game backend (raylib, MonoGame, SDL, …) can produce.

Backends translate their native key types to this DU at the input boundary. Any native key with no logical equivalent maps to KeyCode.Unknown. Cases are RequireQualifiedAccess because names like Up/Down/Left/Right would otherwise collide with user DU cases when Mibo.Input is opened. Always write KeyCode.W, KeyCode.Space, etc.

Union cases

Union case Description

A

Full Usage: A

Apostrophe

Full Usage: Apostrophe

B

Full Usage: B

Backslash

Full Usage: Backslash

Backspace

Full Usage: Backspace

C

Full Usage: C

CapsLock

Full Usage: CapsLock

Comma

Full Usage: Comma

D

Full Usage: D

D0

Full Usage: D0

D1

Full Usage: D1

D2

Full Usage: D2

D3

Full Usage: D3

D4

Full Usage: D4

D5

Full Usage: D5

D6

Full Usage: D6

D7

Full Usage: D7

D8

Full Usage: D8

D9

Full Usage: D9

Delete

Full Usage: Delete

Down

Full Usage: Down

E

Full Usage: E

End

Full Usage: End

Enter

Full Usage: Enter

Equal

Full Usage: Equal

Escape

Full Usage: Escape

F

Full Usage: F

F1

Full Usage: F1

F10

Full Usage: F10

F11

Full Usage: F11

F12

Full Usage: F12

F2

Full Usage: F2

F3

Full Usage: F3

F4

Full Usage: F4

F5

Full Usage: F5

F6

Full Usage: F6

F7

Full Usage: F7

F8

Full Usage: F8

F9

Full Usage: F9

G

Full Usage: G

Grave

Full Usage: Grave

H

Full Usage: H

Home

Full Usage: Home

I

Full Usage: I

Insert

Full Usage: Insert

J

Full Usage: J

K

Full Usage: K

Kp0

Full Usage: Kp0

Kp1

Full Usage: Kp1

Kp2

Full Usage: Kp2

Kp3

Full Usage: Kp3

Kp4

Full Usage: Kp4

Kp5

Full Usage: Kp5

Kp6

Full Usage: Kp6

Kp7

Full Usage: Kp7

Kp8

Full Usage: Kp8

Kp9

Full Usage: Kp9

KpAdd

Full Usage: KpAdd

KpDecimal

Full Usage: KpDecimal

KpDivide

Full Usage: KpDivide

KpEnter

Full Usage: KpEnter

KpEqual

Full Usage: KpEqual

KpMultiply

Full Usage: KpMultiply

KpSubtract

Full Usage: KpSubtract

L

Full Usage: L

Left

Full Usage: Left

LeftAlt

Full Usage: LeftAlt

LeftBracket

Full Usage: LeftBracket

LeftControl

Full Usage: LeftControl

LeftShift

Full Usage: LeftShift

LeftSuper

Full Usage: LeftSuper

M

Full Usage: M

Menu

Full Usage: Menu

Minus

Full Usage: Minus

N

Full Usage: N

NumLock

Full Usage: NumLock

O

Full Usage: O

P

Full Usage: P

PageDown

Full Usage: PageDown

PageUp

Full Usage: PageUp

Pause

Full Usage: Pause

Period

Full Usage: Period

PrintScreen

Full Usage: PrintScreen

Q

Full Usage: Q

R

Full Usage: R

Right

Full Usage: Right

RightAlt

Full Usage: RightAlt

RightBracket

Full Usage: RightBracket

RightControl

Full Usage: RightControl

RightShift

Full Usage: RightShift

RightSuper

Full Usage: RightSuper

S

Full Usage: S

ScrollLock

Full Usage: ScrollLock

Semicolon

Full Usage: Semicolon

Slash

Full Usage: Slash

Space

Full Usage: Space

T

Full Usage: T

Tab

Full Usage: Tab

U

Full Usage: U

Unknown

Full Usage: Unknown

Up

Full Usage: Up

V

Full Usage: V

W

Full Usage: W

X

Full Usage: X

Y

Full Usage: Y

Z

Full Usage: Z

Instance members

Instance member Description

this.IsA

Full Usage: this.IsA

Returns: bool
Returns: bool

this.IsApostrophe

Full Usage: this.IsApostrophe

Returns: bool
Returns: bool

this.IsB

Full Usage: this.IsB

Returns: bool
Returns: bool

this.IsBackslash

Full Usage: this.IsBackslash

Returns: bool
Returns: bool

this.IsBackspace

Full Usage: this.IsBackspace

Returns: bool
Returns: bool

this.IsC

Full Usage: this.IsC

Returns: bool
Returns: bool

this.IsCapsLock

Full Usage: this.IsCapsLock

Returns: bool
Returns: bool

this.IsComma

Full Usage: this.IsComma

Returns: bool
Returns: bool

this.IsD

Full Usage: this.IsD

Returns: bool
Returns: bool

this.IsD0

Full Usage: this.IsD0

Returns: bool
Returns: bool

this.IsD1

Full Usage: this.IsD1

Returns: bool
Returns: bool

this.IsD2

Full Usage: this.IsD2

Returns: bool
Returns: bool

this.IsD3

Full Usage: this.IsD3

Returns: bool
Returns: bool

this.IsD4

Full Usage: this.IsD4

Returns: bool
Returns: bool

this.IsD5

Full Usage: this.IsD5

Returns: bool
Returns: bool

this.IsD6

Full Usage: this.IsD6

Returns: bool
Returns: bool

this.IsD7

Full Usage: this.IsD7

Returns: bool
Returns: bool

this.IsD8

Full Usage: this.IsD8

Returns: bool
Returns: bool

this.IsD9

Full Usage: this.IsD9

Returns: bool
Returns: bool

this.IsDelete

Full Usage: this.IsDelete

Returns: bool
Returns: bool

this.IsDown

Full Usage: this.IsDown

Returns: bool
Returns: bool

this.IsE

Full Usage: this.IsE

Returns: bool
Returns: bool

this.IsEnd

Full Usage: this.IsEnd

Returns: bool
Returns: bool

this.IsEnter

Full Usage: this.IsEnter

Returns: bool
Returns: bool

this.IsEqual

Full Usage: this.IsEqual

Returns: bool
Returns: bool

this.IsEscape

Full Usage: this.IsEscape

Returns: bool
Returns: bool

this.IsF

Full Usage: this.IsF

Returns: bool
Returns: bool

this.IsF1

Full Usage: this.IsF1

Returns: bool
Returns: bool

this.IsF10

Full Usage: this.IsF10

Returns: bool
Returns: bool

this.IsF11

Full Usage: this.IsF11

Returns: bool
Returns: bool

this.IsF12

Full Usage: this.IsF12

Returns: bool
Returns: bool

this.IsF2

Full Usage: this.IsF2

Returns: bool
Returns: bool

this.IsF3

Full Usage: this.IsF3

Returns: bool
Returns: bool

this.IsF4

Full Usage: this.IsF4

Returns: bool
Returns: bool

this.IsF5

Full Usage: this.IsF5

Returns: bool
Returns: bool

this.IsF6

Full Usage: this.IsF6

Returns: bool
Returns: bool

this.IsF7

Full Usage: this.IsF7

Returns: bool
Returns: bool

this.IsF8

Full Usage: this.IsF8

Returns: bool
Returns: bool

this.IsF9

Full Usage: this.IsF9

Returns: bool
Returns: bool

this.IsG

Full Usage: this.IsG

Returns: bool
Returns: bool

this.IsGrave

Full Usage: this.IsGrave

Returns: bool
Returns: bool

this.IsH

Full Usage: this.IsH

Returns: bool
Returns: bool

this.IsHome

Full Usage: this.IsHome

Returns: bool
Returns: bool

this.IsI

Full Usage: this.IsI

Returns: bool
Returns: bool

this.IsInsert

Full Usage: this.IsInsert

Returns: bool
Returns: bool

this.IsJ

Full Usage: this.IsJ

Returns: bool
Returns: bool

this.IsK

Full Usage: this.IsK

Returns: bool
Returns: bool

this.IsKp0

Full Usage: this.IsKp0

Returns: bool
Returns: bool

this.IsKp1

Full Usage: this.IsKp1

Returns: bool
Returns: bool

this.IsKp2

Full Usage: this.IsKp2

Returns: bool
Returns: bool

this.IsKp3

Full Usage: this.IsKp3

Returns: bool
Returns: bool

this.IsKp4

Full Usage: this.IsKp4

Returns: bool
Returns: bool

this.IsKp5

Full Usage: this.IsKp5

Returns: bool
Returns: bool

this.IsKp6

Full Usage: this.IsKp6

Returns: bool
Returns: bool

this.IsKp7

Full Usage: this.IsKp7

Returns: bool
Returns: bool

this.IsKp8

Full Usage: this.IsKp8

Returns: bool
Returns: bool

this.IsKp9

Full Usage: this.IsKp9

Returns: bool
Returns: bool

this.IsKpAdd

Full Usage: this.IsKpAdd

Returns: bool
Returns: bool

this.IsKpDecimal

Full Usage: this.IsKpDecimal

Returns: bool
Returns: bool

this.IsKpDivide

Full Usage: this.IsKpDivide

Returns: bool
Returns: bool

this.IsKpEnter

Full Usage: this.IsKpEnter

Returns: bool
Returns: bool

this.IsKpEqual

Full Usage: this.IsKpEqual

Returns: bool
Returns: bool

this.IsKpMultiply

Full Usage: this.IsKpMultiply

Returns: bool
Returns: bool

this.IsKpSubtract

Full Usage: this.IsKpSubtract

Returns: bool
Returns: bool

this.IsL

Full Usage: this.IsL

Returns: bool
Returns: bool

this.IsLeft

Full Usage: this.IsLeft

Returns: bool
Returns: bool

this.IsLeftAlt

Full Usage: this.IsLeftAlt

Returns: bool
Returns: bool

this.IsLeftBracket

Full Usage: this.IsLeftBracket

Returns: bool
Returns: bool

this.IsLeftControl

Full Usage: this.IsLeftControl

Returns: bool
Returns: bool

this.IsLeftShift

Full Usage: this.IsLeftShift

Returns: bool
Returns: bool

this.IsLeftSuper

Full Usage: this.IsLeftSuper

Returns: bool
Returns: bool

this.IsM

Full Usage: this.IsM

Returns: bool
Returns: bool

this.IsMenu

Full Usage: this.IsMenu

Returns: bool
Returns: bool

this.IsMinus

Full Usage: this.IsMinus

Returns: bool
Returns: bool

this.IsN

Full Usage: this.IsN

Returns: bool
Returns: bool

this.IsNumLock

Full Usage: this.IsNumLock

Returns: bool
Returns: bool

this.IsO

Full Usage: this.IsO

Returns: bool
Returns: bool

this.IsP

Full Usage: this.IsP

Returns: bool
Returns: bool

this.IsPageDown

Full Usage: this.IsPageDown

Returns: bool
Returns: bool

this.IsPageUp

Full Usage: this.IsPageUp

Returns: bool
Returns: bool

this.IsPause

Full Usage: this.IsPause

Returns: bool
Returns: bool

this.IsPeriod

Full Usage: this.IsPeriod

Returns: bool
Returns: bool

this.IsPrintScreen

Full Usage: this.IsPrintScreen

Returns: bool
Returns: bool

this.IsQ

Full Usage: this.IsQ

Returns: bool
Returns: bool

this.IsR

Full Usage: this.IsR

Returns: bool
Returns: bool

this.IsRight

Full Usage: this.IsRight

Returns: bool
Returns: bool

this.IsRightAlt

Full Usage: this.IsRightAlt

Returns: bool
Returns: bool

this.IsRightBracket

Full Usage: this.IsRightBracket

Returns: bool
Returns: bool

this.IsRightControl

Full Usage: this.IsRightControl

Returns: bool
Returns: bool

this.IsRightShift

Full Usage: this.IsRightShift

Returns: bool
Returns: bool

this.IsRightSuper

Full Usage: this.IsRightSuper

Returns: bool
Returns: bool

this.IsS

Full Usage: this.IsS

Returns: bool
Returns: bool

this.IsScrollLock

Full Usage: this.IsScrollLock

Returns: bool
Returns: bool

this.IsSemicolon

Full Usage: this.IsSemicolon

Returns: bool
Returns: bool

this.IsSlash

Full Usage: this.IsSlash

Returns: bool
Returns: bool

this.IsSpace

Full Usage: this.IsSpace

Returns: bool
Returns: bool

this.IsT

Full Usage: this.IsT

Returns: bool
Returns: bool

this.IsTab

Full Usage: this.IsTab

Returns: bool
Returns: bool

this.IsU

Full Usage: this.IsU

Returns: bool
Returns: bool

this.IsUnknown

Full Usage: this.IsUnknown

Returns: bool
Returns: bool

this.IsUp

Full Usage: this.IsUp

Returns: bool
Returns: bool

this.IsV

Full Usage: this.IsV

Returns: bool
Returns: bool

this.IsW

Full Usage: this.IsW

Returns: bool
Returns: bool

this.IsX

Full Usage: this.IsX

Returns: bool
Returns: bool

this.IsY

Full Usage: this.IsY

Returns: bool
Returns: bool

this.IsZ

Full Usage: this.IsZ

Returns: bool
Returns: bool

Type something to start searching.