BoxStyle<'T> Type
A box style: paints the whole area of the element it is applied to, relative to that area. Box styles never take coordinates; they combine in `Stamp.box` and `Flow.canvas` (`Flow.fill`, `Flow.border`, `Flow.noise`, ...).
Mibo
GridSection2D<'T> -> unit
obj
A box style: paints the whole area of the element it is applied to, relative to that area. Box styles never take coordinates; they combine in `Stamp.box` and `Flow.canvas` (`Flow.fill`, `Flow.border`, `Flow.noise`, ...).