DockSpec<'T> Type
A dock spec: where the element anchors (`Anchor`, combining `Dock` values with `|||`, for example `Dock.Top ||| Dock.CenterX`), the per-side inset from the container edges in cells, and the element to dock.
A dock spec: where the element anchors (`Anchor`, combining `Dock` values with `|||`, for example `Dock.Top ||| Dock.CenterX`), the per-side inset from the container edges in cells, and the element to dock.