Logo Mibo

FlowOpts Type

Options for `Flow.row` and `Flow.column` containers.

Record fields

Record Field Description

Align

Full Usage: Align

Field type: Align

Cross-axis alignment of children inside the container.

Field type: Align

Gap

Full Usage: Gap

Field type: int

Empty cells inserted between children on the main axis.

Field type: int

Justify

Full Usage: Justify

Field type: Align

Main-axis distribution of the children of each line.

Field type: Align

Wrap

Full Usage: Wrap

Field type: bool

Wrap children onto new lines when they exceed the container length.

Field type: bool

Static members

Static member Description

FlowOpts.Default

Full Usage: FlowOpts.Default

Returns: FlowOpts

Default options: no gap, start alignment, no wrap.

Returns: FlowOpts

Type something to start searching.