Header menu logo Mibo

HexLayout Module

Functions and values

Function or value Description

border col row width height content section

Full Usage: border col row width height content section

Parameters:
    col : int
    row : int
    width : int
    height : int
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
col : int
row : int
width : int
height : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

center w h f parent

Full Usage: center w h f parent

Parameters:
Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
w : int
h : int
f : HexGridSection<'T> -> HexGridSection<'T>
parent : HexGridSection<'T>
Returns: HexGridSection<'T>

checker odd even section

Full Usage: checker odd even section

Parameters:
Returns: HexGridSection<'T>
odd : 'T
even : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

checkerBorder col row width height odd even section

Full Usage: checkerBorder col row width height odd even section

Parameters:
    col : int
    row : int
    width : int
    height : int
    odd : 'T
    even : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
col : int
row : int
width : int
height : int
odd : 'T
even : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

circle cc cr radius filled content section

Full Usage: circle cc cr radius filled content section

Parameters:
    cc : int
    cr : int
    radius : int
    filled : bool
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
cc : int
cr : int
radius : int
filled : bool
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

clear col row width height section

Full Usage: clear col row width height section

Parameters:
    col : int
    row : int
    width : int
    height : int
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
col : int
row : int
width : int
height : int
section : HexGridSection<'T>
Returns: HexGridSection<'T>

corners col row width height content section

Full Usage: corners col row width height content section

Parameters:
    col : int
    row : int
    width : int
    height : int
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
col : int
row : int
width : int
height : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

fill col row width height content section

Full Usage: fill col row width height content section

Parameters:
    col : int
    row : int
    width : int
    height : int
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
col : int
row : int
width : int
height : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

flowX step stamps parent

Full Usage: flowX step stamps parent

Parameters:
Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
step : int
stamps : (HexGridSection<'T> -> HexGridSection<'T>) seq
parent : HexGridSection<'T>
Returns: HexGridSection<'T>

flowY step stamps parent

Full Usage: flowY step stamps parent

Parameters:
Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
step : int
stamps : (HexGridSection<'T> -> HexGridSection<'T>) seq
parent : HexGridSection<'T>
Returns: HexGridSection<'T>

generate col row width height generator section

Full Usage: generate col row width height generator section

Parameters:
    col : int
    row : int
    width : int
    height : int
    generator : int -> int -> 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
width : int
height : int
generator : int -> int -> 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

iter col row width height action section

Full Usage: iter col row width height action section

Parameters:
    col : int
    row : int
    width : int
    height : int
    action : int -> int -> 'T voption -> unit
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
width : int
height : int
action : int -> int -> 'T voption -> unit
section : HexGridSection<'T>
Returns: HexGridSection<'T>

line c1 r1 c2 r2 content section

Full Usage: line c1 r1 c2 r2 content section

Parameters:
    c1 : int
    r1 : int
    c2 : int
    r2 : int
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
c1 : int
r1 : int
c2 : int
r2 : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

map col row width height mapping section

Full Usage: map col row width height mapping section

Parameters:
    col : int
    row : int
    width : int
    height : int
    mapping : 'T -> 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
width : int
height : int
mapping : 'T -> 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

padding n f parent

Full Usage: padding n f parent

Parameters:
Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
n : int
f : HexGridSection<'T> -> HexGridSection<'T>
parent : HexGridSection<'T>
Returns: HexGridSection<'T>

paddingEx left top right bottom f parent

Full Usage: paddingEx left top right bottom f parent

Parameters:
Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
left : int
top : int
right : int
bottom : int
f : HexGridSection<'T> -> HexGridSection<'T>
parent : HexGridSection<'T>
Returns: HexGridSection<'T>

polygon points filled content section

Full Usage: polygon points filled content section

Parameters:
    points : (int * int)[]
    filled : bool
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
points : (int * int)[]
filled : bool
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

rect col row width height borderContent fillContent section

Full Usage: rect col row width height borderContent fillContent section

Parameters:
    col : int
    row : int
    width : int
    height : int
    borderContent : 'T
    fillContent : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
col : int
row : int
width : int
height : int
borderContent : 'T
fillContent : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

repeatX col row count content section

Full Usage: repeatX col row count content section

Parameters:
    col : int
    row : int
    count : int
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
col : int
row : int
count : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

repeatY col row count content section

Full Usage: repeatY col row count content section

Parameters:
    col : int
    row : int
    count : int
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
col : int
row : int
count : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

replace oldContent newContent section

Full Usage: replace oldContent newContent section

Parameters:
Returns: HexGridSection<'T>
oldContent : 'T
newContent : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

replaceScatter oldContent newContent probability seed section

Full Usage: replaceScatter oldContent newContent probability seed section

Parameters:
    oldContent : 'T
    newContent : 'T
    probability : float32
    seed : int
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
oldContent : 'T
newContent : 'T
probability : float32
seed : int
section : HexGridSection<'T>
Returns: HexGridSection<'T>

run f grid

Full Usage: run f grid

Parameters:
Returns: HexGrid<'T>
Modifiers: inline
Type parameters: 'T
f : HexGridSection<'T> -> HexGridSection<'T>
grid : HexGrid<'T>
Returns: HexGrid<'T>

scatter count seed content section

Full Usage: scatter count seed content section

Parameters:
Returns: HexGridSection<'T>
count : int
seed : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

scatterBorder col row width height count seed content section

Full Usage: scatterBorder col row width height count seed content section

Parameters:
    col : int
    row : int
    width : int
    height : int
    count : int
    seed : int
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
col : int
row : int
width : int
height : int
count : int
seed : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

scatterLine c1 r1 c2 r2 count seed content section

Full Usage: scatterLine c1 r1 c2 r2 count seed content section

Parameters:
    c1 : int
    r1 : int
    c2 : int
    r2 : int
    count : int
    seed : int
    content : 'T
    section : HexGridSection<'T>

Returns: HexGridSection<'T>
c1 : int
r1 : int
c2 : int
r2 : int
count : int
seed : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

scatterStamp count seed stamp section'

Full Usage: scatterStamp count seed stamp section'

Parameters:
Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
count : int
seed : int
stamp : HexGridSection<'T> -> HexGridSection<'T>
section' : HexGridSection<'T>
Returns: HexGridSection<'T>

section col row f parent

Full Usage: section col row f parent

Parameters:
Returns: HexGridSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
f : HexGridSection<'T> -> HexGridSection<'T>
parent : HexGridSection<'T>
Returns: HexGridSection<'T>

set col row content section

Full Usage: set col row content section

Parameters:
Returns: HexGridSection<'T>
col : int
row : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

setIfEmpty col row content section

Full Usage: setIfEmpty col row content section

Parameters:
Returns: HexGridSection<'T>
col : int
row : int
content : 'T
section : HexGridSection<'T>
Returns: HexGridSection<'T>

Type something to start searching.