Header menu logo Mibo

HexLayout3D Module

Functions and values

Function or value Description

border col row layer w h d content section

Full Usage: border col row layer w h d content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

center w h d f parent

Full Usage: center w h d f parent

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
w : int
h : int
d : int
f : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

checker odd even section

Full Usage: checker odd even section

Parameters:
Returns: HexGrid3DSection<'T>
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

checker3D odd even section

Full Usage: checker3D odd even section

Parameters:
Returns: HexGrid3DSection<'T>
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

checkerBorder col row layer w h d odd even section

Full Usage: checkerBorder col row layer w h d odd even section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    odd : 'T
    even : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

checkerHexLayer layer odd even section

Full Usage: checkerHexLayer layer odd even section

Parameters:
Returns: HexGrid3DSection<'T>
layer : int
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

checkerShell col row layer w h d odd even section'

Full Usage: checkerShell col row layer w h d odd even section'

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    odd : 'T
    even : 'T
    section' : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
odd : 'T
even : 'T
section' : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

checkerXY row odd even section

Full Usage: checkerXY row odd even section

Parameters:
Returns: HexGrid3DSection<'T>
row : int
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

checkerYZ col odd even section

Full Usage: checkerYZ col odd even section

Parameters:
Returns: HexGrid3DSection<'T>
col : int
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

clear col row layer w h d section

Full Usage: clear col row layer w h d section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

column col row layer height content section

Full Usage: column col row layer height content section

Parameters:
    col : int
    row : int
    layer : int
    height : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
layer : int
height : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

corners col row layer w h d content section

Full Usage: corners col row layer w h d content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

cylinder cc cr layer radius height filled content section

Full Usage: cylinder cc cr layer radius height filled content section

Parameters:
    cc : int
    cr : int
    layer : int
    radius : int
    height : int
    filled : bool
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
cc : int
cr : int
layer : int
radius : int
height : int
filled : bool
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

edges col row layer w h d content section

Full Usage: edges col row layer w h d content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

fill col row layer w h d content section

Full Usage: fill col row layer w h d content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

floorHex col row layer w d content section

Full Usage: floorHex col row layer w d content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    d : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

flowX step stamps parent

Full Usage: flowX step stamps parent

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
step : int
stamps : (HexGrid3DSection<'T> -> HexGrid3DSection<'T>) seq
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

flowY step stamps parent

Full Usage: flowY step stamps parent

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
step : int
stamps : (HexGrid3DSection<'T> -> HexGrid3DSection<'T>) seq
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

flowZ step stamps parent

Full Usage: flowZ step stamps parent

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
step : int
stamps : (HexGrid3DSection<'T> -> HexGrid3DSection<'T>) seq
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

generate col row layer w h d generator section

Full Usage: generate col row layer w h d generator section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    generator : int -> int -> int -> 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
layer : int
w : int
h : int
d : int
generator : int -> int -> int -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

generateHexLayer layer generator section

Full Usage: generateHexLayer layer generator section

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
layer : int
generator : int -> int -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

generateXY row generator section

Full Usage: generateXY row generator section

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
row : int
generator : int -> int -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

generateYZ col generator section

Full Usage: generateYZ col generator section

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
generator : int -> int -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

iter col row layer w h d action section

Full Usage: iter col row layer w h d action section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    action : int -> int -> int -> 'T voption -> unit
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
layer : int
w : int
h : int
d : int
action : int -> int -> int -> 'T voption -> unit
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

line c1 r1 l1 c2 r2 l2 content section

Full Usage: line c1 r1 l1 c2 r2 l2 content section

Parameters:
    c1 : int
    r1 : int
    l1 : int
    c2 : int
    r2 : int
    l2 : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
c1 : int
r1 : int
l1 : int
c2 : int
r2 : int
l2 : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

map col row layer w h d mapping section

Full Usage: map col row layer w h d mapping section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    mapping : 'T -> 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
layer : int
w : int
h : int
d : int
mapping : 'T -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

padding n f parent

Full Usage: padding n f parent

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
n : int
f : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

paddingEx left bottom back right top front f parent

Full Usage: paddingEx left bottom back right top front f parent

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
left : int
bottom : int
back : int
right : int
top : int
front : int
f : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

rect col row layer w h d borderContent fillContent section

Full Usage: rect col row layer w h d borderContent fillContent section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    borderContent : 'T
    fillContent : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
borderContent : 'T
fillContent : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

repeatX col row layer count content section

Full Usage: repeatX col row layer count content section

Parameters:
    col : int
    row : int
    layer : int
    count : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
count : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

repeatY col row layer count content section

Full Usage: repeatY col row layer count content section

Parameters:
    col : int
    row : int
    layer : int
    count : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
count : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

repeatZ col row layer count content section

Full Usage: repeatZ col row layer count content section

Parameters:
    col : int
    row : int
    layer : int
    count : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
count : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

replace oldContent newContent section

Full Usage: replace oldContent newContent section

Parameters:
Returns: HexGrid3DSection<'T>
oldContent : 'T
newContent : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

replaceScatter oldContent newContent probability seed section

Full Usage: replaceScatter oldContent newContent probability seed section

Parameters:
    oldContent : 'T
    newContent : 'T
    probability : float32
    seed : int
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
oldContent : 'T
newContent : 'T
probability : float32
seed : int
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

run f grid

Full Usage: run f grid

Parameters:
Returns: HexGrid3D<'T>
Modifiers: inline
Type parameters: 'T
f : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
grid : HexGrid3D<'T>
Returns: HexGrid3D<'T>

scatter count seed content section

Full Usage: scatter count seed content section

Parameters:
Returns: HexGrid3DSection<'T>
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

scatter3D count seed content section

Full Usage: scatter3D count seed content section

Parameters:
Returns: HexGrid3DSection<'T>
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

scatterBorder col row layer w h d count seed content section

Full Usage: scatterBorder col row layer w h d count seed content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    count : int
    seed : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

scatterEdges col row layer w h d count seed content section

Full Usage: scatterEdges col row layer w h d count seed content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    count : int
    seed : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

scatterHexLayer layer count seed content section

Full Usage: scatterHexLayer layer count seed content section

Parameters:
    layer : int
    count : int
    seed : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
layer : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

scatterLine c1 r1 l1 c2 r2 l2 count seed content section

Full Usage: scatterLine c1 r1 l1 c2 r2 l2 count seed content section

Parameters:
    c1 : int
    r1 : int
    l1 : int
    c2 : int
    r2 : int
    l2 : int
    count : int
    seed : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
c1 : int
r1 : int
l1 : int
c2 : int
r2 : int
l2 : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

scatterShell col row layer w h d count seed content section

Full Usage: scatterShell col row layer w h d count seed content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    count : int
    seed : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

scatterStamp count seed stamp section'

Full Usage: scatterStamp count seed stamp section'

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
count : int
seed : int
stamp : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
section' : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

scatterXY row count seed content section

Full Usage: scatterXY row count seed content section

Parameters:
Returns: HexGrid3DSection<'T>
row : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

scatterYZ col count seed content section

Full Usage: scatterYZ col count seed content section

Parameters:
Returns: HexGrid3DSection<'T>
col : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

section col row layer f parent

Full Usage: section col row layer f parent

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
layer : int
f : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

set col row layer content section

Full Usage: set col row layer content section

Parameters:
Returns: HexGrid3DSection<'T>
Modifiers: inline
Type parameters: 'T
col : int
row : int
layer : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

setIfEmpty col row layer content section

Full Usage: setIfEmpty col row layer content section

Parameters:
Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

shell col row layer w h d content section

Full Usage: shell col row layer w h d content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    d : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

sphere cc cr cl radius filled content section

Full Usage: sphere cc cr cl radius filled content section

Parameters:
    cc : int
    cr : int
    cl : int
    radius : int
    filled : bool
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
cc : int
cr : int
cl : int
radius : int
filled : bool
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

wallXY col row layer w h content section

Full Usage: wallXY col row layer w h content section

Parameters:
    col : int
    row : int
    layer : int
    w : int
    h : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
w : int
h : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

wallYZ col row layer h d content section

Full Usage: wallYZ col row layer h d content section

Parameters:
    col : int
    row : int
    layer : int
    h : int
    d : int
    content : 'T
    section : HexGrid3DSection<'T>

Returns: HexGrid3DSection<'T>
col : int
row : int
layer : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>

Type something to start searching.