Logo Mibo

ElementDecl<'T> Type

One element declared by the game: a name, an optional intrinsic size, and a body of operations. Variations are separate declarations (six corridor directions are six declarations from one F# builder); there are no parameters.

Record fields

Record Field Description

Body

Full Usage: Body

Field type: Op<'T>[]
Field type: Op<'T>[]

Extent

Full Usage: Extent

Field type: CellSize voption
Field type: CellSize voption

Name

Full Usage: Name

Field type: string
Field type: string

Type something to start searching.