Mibo.Windowing Namespace
| Type/Module | Description |
|
Runtime window control, registered by the host in the GameContext. |
|
|
Service accessors for the registered IWindow. |
|
|
Window presentation mode. |
| Type/Module | Description |
|
Runtime window control, registered by the host in the GameContext. |
|
|
Service accessors for the registered IWindow. |
|
|
Window presentation mode. |