Choose2MapNode<'K, 'V1, 'V2, 'V3> Type
Merges two maps with a mapping over both side values (voptions). The mapping decides the semantics: choose2, intersect(With), union(With) are all this node with different mappings (FDA models them all on Choose2VReader). The mapping is called only when at least one side has a value; the sides' current values are tracked per key.
Constructors
| Constructor |
Description
|
Full Usage:
Choose2MapNode(left, right, mapping)
Parameters:
IAdaptiveMap<'K, 'V1>
right : IAdaptiveMap<'K, 'V2>
mapping : 'K -> 'V1 voption -> 'V2 voption -> 'V3 voption
Returns: Choose2MapNode<'K, 'V1, 'V2, 'V3>
|
|
Mibo