CList Module
Operations on changeable lists.
Functions and values
| Function or value |
Description
|
Full Usage:
addRange items list
Parameters:
'T seq
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Appends all the given elements (FDA
|
Full Usage:
append value list
Parameters:
'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Appends an element at the end of the list.
|
|
Removes all elements.
|
An empty changeable list.
|
|
Full Usage:
force list
Parameters:
clist<'T>
Returns: 'T[]
Modifiers: inline Type parameters: 'T |
|
Full Usage:
insertAt position value list
Parameters:
int
value : 'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Inserts an element before the element currently at the position.
|
Full Usage:
ofArray items
Parameters:
'T[]
Returns: clist<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
ofList items
Parameters:
'T list
Returns: clist<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
ofSeq items
Parameters:
'T seq
Returns: clist<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
perform delta list
Parameters:
ListDeltaBuilder<'T>
list : clist<'T>
Type parameters: 'T |
Applies a batch of list operations (FDA
|
Full Usage:
postAppend value list
Parameters:
'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Posts an append (the
Example
val view: obj
|
|
Posts a clear. Safe from any thread. See postAppend for the application contract.
|
Full Usage:
postInsertAt position value list
Parameters:
int
value : 'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Posts an insert before the element currently at the position. Safe from any thread. See postAppend for the application contract.
|
Full Usage:
postPrepend value list
Parameters:
'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Posts an insert at the start. Safe from any thread. See postAppend for the application contract.
|
Full Usage:
postRemove value list
Parameters:
'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Posts a remove of the first occurrence of the value. Safe from any thread. See postAppend for the application contract.
|
Full Usage:
postRemoveAt position list
Parameters:
int
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Posts a remove at the position. Safe from any thread. See postAppend for the application contract.
|
Full Usage:
postSet values list
Parameters:
'T seq
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Posts a full replace. Safe from any thread. See postAppend for the application contract; a posted replace supersedes the other ops of the same pending batch (the transaction semantics of set).
|
Full Usage:
postUpdateAt position value list
Parameters:
int
value : 'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Posts a replace at the position. Safe from any thread. See postAppend for the application contract.
|
Full Usage:
prepend value list
Parameters:
'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Inserts an element at the start of the list.
|
Full Usage:
remove value list
Parameters:
'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Removes the first occurrence of the value. No-op when absent.
|
Full Usage:
removeAt position list
Parameters:
int
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Removes the element currently at the position.
|
Full Usage:
set values list
Parameters:
'T seq
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Replaces the whole list. Last-wins over the whole batch inside a transaction.
|
Full Usage:
toList list
Parameters:
clist<'T>
Returns: 'T list
Modifiers: inline Type parameters: 'T |
|
Full Usage:
updateAt position value list
Parameters:
int
value : 'T
list : clist<'T>
Modifiers: inline Type parameters: 'T |
Replaces the element currently at the position.
|
Full Usage:
updateTo target list
Parameters:
'T[]
list : clist<'T>
Returns: bool
Modifiers: inline Type parameters: 'T |
Replaces the whole list and returns whether the content changed (FDA
|
|
Mibo