ListDeltaBuilder<'T> Type
A class-based delta builder for AList.custom computes. The struct ListDelta<'T> is passed by value (its counter would be copied); this class keeps the appends visible to the node.
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Insert
Parameters:
int
value : 'T
|
Appends an insert operation. Positions refer to the state as of the previous operation.
|
Full Usage:
this.Remove
Parameters:
int
|
Appends a remove operation. Positions refer to the state as of the previous operation.
|
Full Usage:
this.Update
Parameters:
int
value : 'T
|
Appends an update operation. Positions refer to the state as of the previous operation.
|
Mibo