OfAvalMapNode<'K, 'V, 'S> Type
An adaptive map over an adaptive value of a sequence of entries. Every change of the value replaces the whole state and emits the diff as the delta (the rebuild boundary, like OfAvalSetNode).
Constructors
| Constructor |
Description
|
Full Usage:
OfAvalMapNode(value)
Parameters:
IAdaptiveValue<'S>
Returns: OfAvalMapNode<'K, 'V, 'S>
|
|
Mibo