OfAvalSetNode<'T, 'S> Type
An adaptive set over an adaptive value of a sequence. Every change of the
value replaces the whole state and emits the diff as the delta (the value
carries no deltas; this node is the rebuild boundary, like FDA
ASet.ofAVal).
Constructors
| Constructor |
Description
|
Full Usage:
OfAvalSetNode(value)
Parameters:
IAdaptiveValue<'S>
Returns: OfAvalSetNode<'T, 'S>
|
|
Mibo