SetToMapNode<'K, 'V, 'T> Type
A map from a set: every element maps to an entry. When multiple elements
map to one key, the last value wins (ofASetIgnoreDuplicates); a
removal of an entry whose value is not the current one is a no-op (gated).
mapSet uses an unconditional removal (a set key appears once).
Constructors
| Constructor |
Description
|
Full Usage:
SetToMapNode(source, toEntry, gated)
Parameters:
IAdaptiveSet<'T>
toEntry : 'T -> 'K * 'V
gated : bool
Returns: SetToMapNode<'K, 'V, 'T>
|
|
Mibo