Header menu logo Mibo

Mibo.Animation Namespace

Type/Module Description

AnimatedMesh (Module)

AnimatedMesh (Type)

A mesh with skeleton data for GPU skinning.

AnimatedSprite (Module)

Functions for creating, updating, and drawing animated sprites.

AnimatedSprite (Module)

Functions for creating, updating, and drawing animated sprites.

AnimatedSprite (Type)

Runtime state for a playing animation.

AnimatedSprite (Type)

Runtime state for a playing animation.

Animation (Module)

Animation (Module)

Animation (Type)

A single animation with pre-computed frame rectangles.

Animation (Type)

A single animation with pre-computed frame rectangles.

Animation3DClips (Module)

Animation3DClips (Type)

A loaded set of 3D animation clips extracted from a model file.

Animation3DState (Module)

Animation3DState (Type)

Runtime state for a playing 3D skeletal animation.

GridAnimationDef (Type)

Definition for an animation in a grid-based sprite sheet.

GridAnimationDef (Type)

Definition for an animation in a grid-based sprite sheet.

Point (Type)

A 2D point with integer coordinates.

Point (Type)

A 2D point with integer coordinates.

SpriteSheet (Module)

Functions for creating sprite sheets from various sources.

SpriteSheet (Module)

Functions for creating sprite sheets from various sources.

SpriteSheet (Type)

A loaded sprite sheet with texture and named animations.

SpriteSheet (Type)

A loaded sprite sheet with texture and named animations.

Type something to start searching.