Mibo.Animation Namespace
| Type/Module | Description |
|
|
|
|
A mesh with skeleton data for GPU skinning. |
|
|
Functions for creating, updating, and drawing animated sprites. |
|
|
Functions for creating, updating, and drawing animated sprites. |
|
|
Runtime state for a playing animation. |
|
|
Runtime state for a playing animation. |
|
|
|
|
|
|
|
|
A single animation with pre-computed frame rectangles. |
|
|
A single animation with pre-computed frame rectangles. |
|
|
|
|
|
A loaded set of 3D animation clips extracted from a model file. |
|
|
|
|
|
Runtime state for a playing 3D skeletal animation. |
|
|
Definition for an animation in a grid-based sprite sheet. |
|
|
Definition for an animation in a grid-based sprite sheet. |
|
|
A 2D point with integer coordinates. |
|
|
A 2D point with integer coordinates. |
|
|
Functions for creating sprite sheets from various sources. |
|
|
Functions for creating sprite sheets from various sources. |
|
|
A loaded sprite sheet with texture and named animations. |
|
|
A loaded sprite sheet with texture and named animations. |
Mibo