AnimatedMesh Module
Functions and values
| Function or value |
Description
|
Full Usage:
computeBoneMatrices clip frame mesh
Parameters:
ModelAnimation
frame : float32
mesh : AnimatedMesh
Returns: Matrix4x4[]
|
Compute bone matrices for a given animation clip and frame.
This is pure math — does not mutate the model. The result can be passed
directly to
|
|
Extract an
The model must have been loaded from a file that contains skeleton data (glb/gltf/iqm).
Returns
|
Full Usage:
tryFindBoneIndex name mesh
Parameters:
string
mesh : AnimatedMesh
Returns: int voption
Modifiers: inline |
Try to find the index of a bone by its authored name.
Returns
|
Mibo