Mibo.Diagnostics Namespace
| Type/Module | Description |
|
Access to the frame profiler and a display helper. |
|
|
Collects frame measurements for the running game and serves screenshot requests. |
|
|
Frame measurements collected over a time window. |
|
|
Screen capture for the MonoGame backends. |
|
|
Screen capture for the raylib backend. |
Mibo