PostProcessPass Type
A single post-processing pass applied to the rendered scene.
Record fields
| Record Field |
Description
|
Effect used for this pass. Receives the scene/render-target as the active texture.
|
|
|
Optional callback to set effect parameters before rendering the fullscreen quad. Called once per frame when this pass executes. The Effect technique pass is already applied when this callback runs.
|
Mibo