FullScreenQuad Type
A reusable fullscreen quad for post-process blits. Built against a graphics device on first use; FullScreenQuad.Draw applies an effect over a two-triangle quad in clip space. The caller is responsible for binding the source texture to a sampler and setting the active render target.
Constructors
| Constructor |
Description
|
|
|
Mibo