MonoGameProgram Module
MonoGame-specific Program builder extensions.
Functions and values
| Function or value |
Description
|
|
Configures the game to register an IInputMapper service backed by MonoGame's polling API.
This registers IInput automatically (equivalent to Program.withInput). The mapper is registered as a service via a Program.ServiceRegistrations
callback that If you want to stay fully "Elmish" (no service access), consider using InputMapper.subscribe instead and handle a single message.
Example
|
Mibo