FlowOpts Type
Options for `Flow.row` and `Flow.column` containers.
Record fields
| Record Field |
Description
|
Cross-axis alignment of children inside the container.
|
|
Full Usage:
Gap
Field type: int
|
Empty cells inserted between children on the main axis.
|
Main-axis distribution of the children of each line.
|
|
Full Usage:
Wrap
Field type: bool
|
Wrap children onto new lines when they exceed the container length.
|
Static members
| Static member |
Description
|
|
Default options: no gap, start alignment, no wrap.
|
Mibo