HexLayout3D Module
Functions and values
| Function or value |
Description
|
Full Usage:
border col row layer w h d content section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
center w h d f parent
Parameters:
int
h : int
d : int
f : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
checker odd even section
Parameters:
'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
checker3D odd even section
Parameters:
'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
checkerBorder col row layer w h d odd even section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
checkerHexLayer layer odd even section
Parameters:
int
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
checkerShell col row layer w h d odd even section'
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
odd : 'T
even : 'T
section' : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
checkerXY row odd even section
Parameters:
int
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
checkerYZ col odd even section
Parameters:
int
odd : 'T
even : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
clear col row layer w h d section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
column col row layer height content section
Parameters:
int
row : int
layer : int
height : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
corners col row layer w h d content section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
cylinder cc cr layer radius height filled content section
Parameters:
int
cr : int
layer : int
radius : int
height : int
filled : bool
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
edges col row layer w h d content section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
fill col row layer w h d content section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
floorHex col row layer w d content section
Parameters:
int
row : int
layer : int
w : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
flowX step stamps parent
Parameters:
int
stamps : (HexGrid3DSection<'T> -> HexGrid3DSection<'T>) seq
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
flowY step stamps parent
Parameters:
int
stamps : (HexGrid3DSection<'T> -> HexGrid3DSection<'T>) seq
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
flowZ step stamps parent
Parameters:
int
stamps : (HexGrid3DSection<'T> -> HexGrid3DSection<'T>) seq
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
generate col row layer w h d generator section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
generator : int -> int -> int -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
generateHexLayer layer generator section
Parameters:
int
generator : int -> int -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
generateXY row generator section
Parameters:
int
generator : int -> int -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
generateYZ col generator section
Parameters:
int
generator : int -> int -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
iter col row layer w h d action section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
action : int -> int -> int -> 'T voption -> unit
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
line c1 r1 l1 c2 r2 l2 content section
Parameters:
int
r1 : int
l1 : int
c2 : int
r2 : int
l2 : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
map col row layer w h d mapping section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
mapping : 'T -> 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
padding n f parent
Parameters:
int
f : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
paddingEx left bottom back right top front f parent
Parameters:
int
bottom : int
back : int
right : int
top : int
front : int
f : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
rect col row layer w h d borderContent fillContent section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
borderContent : 'T
fillContent : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
repeatX col row layer count content section
Parameters:
int
row : int
layer : int
count : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
repeatY col row layer count content section
Parameters:
int
row : int
layer : int
count : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
repeatZ col row layer count content section
Parameters:
int
row : int
layer : int
count : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
replace oldContent newContent section
Parameters:
'T
newContent : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
replaceScatter oldContent newContent probability seed section
Parameters:
'T
newContent : 'T
probability : float32
seed : int
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
run f grid
Parameters:
HexGrid3DSection<'T> -> HexGrid3DSection<'T>
grid : HexGrid3D<'T>
Returns: HexGrid3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
scatter count seed content section
Parameters:
int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
scatter3D count seed content section
Parameters:
int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
scatterBorder col row layer w h d count seed content section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
scatterEdges col row layer w h d count seed content section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
scatterHexLayer layer count seed content section
Parameters:
int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
scatterLine c1 r1 l1 c2 r2 l2 count seed content section
Parameters:
int
r1 : int
l1 : int
c2 : int
r2 : int
l2 : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
scatterShell col row layer w h d count seed content section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
scatterStamp count seed stamp section'
Parameters:
int
seed : int
stamp : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
section' : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
scatterXY row count seed content section
Parameters:
int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
scatterYZ col count seed content section
Parameters:
int
count : int
seed : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
section col row layer f parent
Parameters:
int
row : int
layer : int
f : HexGrid3DSection<'T> -> HexGrid3DSection<'T>
parent : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
set col row layer content section
Parameters:
int
row : int
layer : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
setIfEmpty col row layer content section
Parameters:
int
row : int
layer : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
shell col row layer w h d content section
Parameters:
int
row : int
layer : int
w : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
sphere cc cr cl radius filled content section
Parameters:
int
cr : int
cl : int
radius : int
filled : bool
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
wallXY col row layer w h content section
Parameters:
int
row : int
layer : int
w : int
h : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Full Usage:
wallYZ col row layer h d content section
Parameters:
int
row : int
layer : int
h : int
d : int
content : 'T
section : HexGrid3DSection<'T>
Returns: HexGrid3DSection<'T>
|
|
Mibo