ElementDecl<'T> Type
One element declared by the game: a name, an optional intrinsic size, and a body of operations. Variations are separate declarations (six corridor directions are six declarations from one F# builder); there are no parameters.
One element declared by the game: a name, an optional intrinsic size, and a body of operations. Variations are separate declarations (six corridor directions are six declarations from one F# builder); there are no parameters.